@@ -107,4 +107,10 @@ class CompareFaceVerifyRequest(RpcRequest):
 		return self.get_body_params().get('SourceCertifyId')
 
 	def set_SourceCertifyId(self,SourceCertifyId):
-		self.add_body_params('SourceCertifyId', SourceCertifyId)
\ No newline at end of file
+		self.add_body_params('SourceCertifyId', SourceCertifyId)
+
+	def get_Crop(self):
+		return self.get_body_params().get('Crop')
+
+	def set_Crop(self,Crop):
+		self.add_body_params('Crop', Crop)
\ No newline at end of file
